@@ -12,7 +12,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT      = qw( );
-our $VERSION     = '0.47';
+our $VERSION     = '0.48';
 
 return 1;
 
@@ -41,6 +41,6 @@ Jet's Neural Architecture is a C++ library.
 
 =head1 SEE ALSO
 
-perl(1), AI::jNeural(3), AI::jNeural::arch::neuron(3), AI::jNeural::arch(3), AI::jNeural::nets::kohonen(3), AI::jNeural::nets(3), AI::jNeural::utils::transfer(3), AI::jNeural::utils(3).
+perl(1), AI::jNeural(3), AI::jNeural::arch::neuron(3), AI::jNeural::arch(3), AI::jNeural::nets::backprop(3), AI::jNeural::nets(3), AI::jNeural::nets::kohonen(3), AI::jNeural::utils::transfer(3), AI::jNeural::utils(3).
 
 =cut
